import classnames from 'classnames';
import useMarkdownContext from '../_context';
import classes from './styles.module.scss';

const tagNameMap = {
  h1: 'heading-one',
  h2: 'heading-two',
  h3: 'heading-three',
  h4: 'heading-four',
  h5: 'heading-five',
  h6: 'heading-six',
  p: 'paragraph',
  blockquote: 'blockquote',
  ol: 'bullets',
  ul: 'numbered',
  li: 'item',
  hr: 'rule',
  img: 'image',
  a: 'link',
  b: 'bold',
  i: 'italic',
  code: 'code',
};

export default function Heading({ children, node }) {
  const context = useMarkdownContext();
  const {
    classes: overrideClasses = {},
    nodeProps: allNodeProps = {},
    components: customComponents = {},
    styled = {},
  } = context;

  const { tagName } = node;
  const nodeName = tagNameMap[tagName];
  const Node = customComponents[tagName] || tagName;

  const className = classnames(
    overrideClasses[nodeName],
    { [classes[nodeName]]: styled },
  );

  const nodeProps = allNodeProps[nodeName];

  return (
    <Node
      className={className}
      {...node.properties}
      {...nodeProps}
    >
      {children}
    </Node>
  );
}
