import PropTypes from 'prop-types';
import classnames from 'classnames';
import ClickAwayListener from 'react-click-away-listener';

import classes from './styles.module.scss';

/**
 * Render a drawer at the bottom of the screen.
 */
const DrawerDisplay = function DrawerDisplay(props) {
  const {
    tooltip,
    children,
    zIndex,
    className,
    unstyled,
  } = props;

  const { active } = tooltip.config;

  const onClickAway = () => {
    if (active) {
      tooltip.trigger.deactivate();
    }
  };

  return (
    <ClickAwayListener onClickAway={onClickAway}>
      <div
        className={classnames(
          classes['tooltip-drawer-display'],
          {
            [classes.styled]: !unstyled,
            [classes.active]: active,
          },
          className,
        )}
        style={{ zIndex }}
      >
        {children}
      </div>
    </ClickAwayListener>
  );
};

DrawerDisplay.defaultProps = {
  children: null,
  zIndex: undefined,
  className: undefined,
  unstyled: false,
};

DrawerDisplay.propTypes = {
  /**
   * A tooltip object as provided by `useTooltip`
   */
  tooltip: PropTypes.shape({
    config: PropTypes.shape({
      active: PropTypes.bool,
    }),
    trigger: PropTypes.shape({
      deactivate: PropTypes.func,
    }),
  }).isRequired,
  /**
   * The children to render inside the tooltip
   */
  children: PropTypes.node,
  /**
   * An override for the tooltip's z-index
   */
  zIndex: PropTypes.oneOfType([
    PropTypes.number,
    PropTypes.string,
  ]),
  /**
   * Custom class names to customize the tooltip. Must be recognizable by the
   * classnames library.
   */
  className: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.array,
    PropTypes.object,
  ]),
  /**
   * Prevent default styles from being attached
   */
  unstyled: PropTypes.bool,
};

export default DrawerDisplay;
