import Template from './_advancedTemplate';
import ContentComponent from './_common/ContentComponent';

const AdvancedTooltipMergedProps = Template.bind({});

AdvancedTooltipMergedProps.args = {
  useTooltipOptions: {
    content: ContentComponent,
    props: {
      color: 'darkgreen',
    },
  },
  triggerProps: [
    { props: { text: 'Hello from Tooltip 1!' } },
    {
      props: {
        text: 'Hello from Tooltip 2!',
        color: 'red',
      },
    },
    { props: { text: 'Hello from Tooltip 3!' } },
  ],
};

AdvancedTooltipMergedProps.parameters = {
  docs: {
    description: {
      story: `
Here again we are using the \`useTooltip\` hook to coordinate our own
\`TooltipDisplay\` and \`TooltipTrigger\` components, but now we're setting
up some default props to merge with the tooltip-specific props. We set up the
default props by passing them to the \`useTooltip\` hook, and they get merged
with the props passed to each \`TooltipTrigger\`.
`,
    },
    source: {
      code: `
import { useTooltip, TooltipDisplay, TooltipTrigger } from '@politico/interactive-style';
import MyTooltipContentComponent from './MyTooltipContentComponent';

const MyParentComponent = function MyParentComponent(props) {
  const tooltip = useTooltip({
    content: MyTooltipContentComponent,
    props: {
      color: 'darkgreen',
    },
  });

  return (
    <div>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 1!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        props={{
          text: 'Hello from Tooltip 2!',
          color: 'red',
        }}
      >
        <Target>Tooltip trigger content 2</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 3!' }}
      >
        <Target>Tooltip trigger content 3</Target>
      </TooltipTrigger>
      <TooltipDisplay tooltip={tooltip} />
    </div>
  );
};

export default MyParentComponent;
`,
    },
  },
};

export default AdvancedTooltipMergedProps;
