import Template from './_advancedTemplate';

const AdvancedTooltipPlainContent = Template.bind({});

AdvancedTooltipPlainContent.args = {
  triggerProps: [
    { content: <div style={{ color: 'darkgreen' }}>Plain content 1</div> },
    { content: <div style={{ color: 'darkblue' }}>Plain content 2</div> },
    { content: <div style={{ color: 'darkred' }}>Plain content 3</div> },
  ],
};

AdvancedTooltipPlainContent.parameters = {
  docs: {
    description: {
      story: `
Here again we are using the \`useTooltip\` hook to coordinate our own
\`TooltipDisplay\` and \`TooltipTrigger\` components, but this time we don't
provide any options to \`useTooltip\` and pass plain, pre-rendered content as
the \`content\` prop to each \`TooltipTrigger\` instead. This means the content
will be rendered as-is.
`,
    },
    source: {
      code: `
import { useTooltip, TooltipDisplay, TooltipTrigger } from '@politico/interactive-style';

const MyParentComponent = function MyParentComponent(props) {
  const tooltip = useTooltip();

  return (
    <div>
      <TooltipTrigger
        tooltip={tooltip}
        content={<div style={{ color: 'darkgreen' }}>Plain content 1</div>}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        content=<div style={{ color: 'darkblue' }}>Plain content 2</div>}
      >
        <Target>Tooltip trigger content 2</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        content={<div style={{ color: 'darkred' }}>Plain content 3</div>}
      >
        <Target>Tooltip trigger content 3</Target>
      </TooltipTrigger>
      <TooltipDisplay tooltip={tooltip} />
    </div>
  );
};

export default MyParentComponent;
`,
    },
  },
};

export default AdvancedTooltipPlainContent;
