import Template from './_advancedTemplate';
import ContentComponent from './_common/ContentComponent';

const AdvancedTooltipMergedProps = Template.bind({});

AdvancedTooltipMergedProps.args = {
  useTooltipOptions: {
    content: ContentComponent,
  },
  displayProps: {
    unstyled: true,
  },
  triggerProps: [
    { props: { text: 'Hello from Tooltip 1!' } },
    {
      label: 'Has a trigger but no tooltip',
      props: { active: false },
    },
  ],
};

AdvancedTooltipMergedProps.parameters = {
  docs: {
    description: {
      story: `
Here again we are using the \`useTooltip\` hook to coordinate our own
\`TooltipDisplay\` and \`TooltipTrigger\` components, but now we're
rendering an unstyled \`TooltipDisplay\`, allowing us to remove the
standard tooltip chrome and take better control of the final product.
`,
    },
    source: {
      code: `
import { useTooltip, TooltipDisplay, TooltipTrigger } from '@politico/interactive-style';
import MyTooltipContentComponent from './MyTooltipContentComponent';

const MyParentComponent = function MyParentComponent(props) {
  const tooltip = useTooltip({
    content: MyTooltipContentComponent,
  });

  return (
    <div>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 1!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipDisplay tooltip={tooltip} unstyled />
    </div>
  );
};

export default MyParentComponent;
`,
    },
  },
};

export default AdvancedTooltipMergedProps;
